@@ -1,22 +1,6 @@
-/***************************************************************************
- *   Copyright Simon Persson                                               *
- *   simonpersson1@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
- ***************************************************************************/
+// SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
+//
+// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
 
 #include "backupjob.h"
 #include "bupjob.h"
@@ -30,9 +14,10 @@
 #endif
 
 #include <QTimer>
+#include <utility>
 
-BackupJob::BackupJob(const BackupPlan &pBackupPlan, const QString &pDestinationPath, const QString &pLogFilePath, KupDaemon *pKupDaemon)
-   :KJob(), mBackupPlan(pBackupPlan), mDestinationPath(pDestinationPath), mLogFilePath(pLogFilePath), mKupDaemon(pKupDaemon)
+BackupJob::BackupJob(BackupPlan &pBackupPlan, QString pDestinationPath, QString pLogFilePath, KupDaemon *pKupDaemon)
+   :mBackupPlan(pBackupPlan), mDestinationPath(std::move(pDestinationPath)), mLogFilePath(std::move(pLogFilePath)), mKupDaemon(pKupDaemon)
 {
 	mLogFile.setFileName(mLogFilePath);
 	mLogFile.open(QIODevice::WriteOnly | QIODevice::Truncate);
@@ -49,7 +34,7 @@ void BackupJob::makeNice(int pPid) {
 	// See linux documentation Documentation/block/ioprio.txt for details of the syscall
 	syscall(SYS_ioprio_set, 1, pPid, 3 << 13 | 7);
 #endif
-	setpriority(PRIO_PROCESS, pPid, 19);
+	setpriority(PRIO_PROCESS, static_cast<uint>(pPid), 19);
 }
 
 QString BackupJob::quoteArgs(const QStringList &pCommand) {
@@ -82,7 +67,7 @@ void BackupJob::jobFinishedSuccess() {
 	emitResult();
 }
 
-void BackupJob::jobFinishedError(BackupJob::ErrorCodes pErrorCode, QString pErrorText) {
+void BackupJob::jobFinishedError(BackupJob::ErrorCodes pErrorCode, const QString &pErrorText) {
 	// if job has already set the error that it was killed by the user then ignore any fault
 	// we get here as that fault is surely about the process exit code was not zero.
 	// And we don't want to report about that (with our notification) in this case.
