@@ -1,33 +1,19 @@
-/***************************************************************************
- *   Copyright Simon Persson                                               *
- *   simonpersson1@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
- ***************************************************************************/
+// SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
+//
+// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
 
 #include "bupjob.h"
 
-#include <signal.h>
+#include <csignal>
 
+#include <QFileInfo>
 #include <QRegularExpression>
 #include <QTextStream>
+#include <QThread>
 
 #include <KLocalizedString>
 
-BupJob::BupJob(const BackupPlan &pBackupPlan, const QString &pDestinationPath, const QString &pLogFilePath, KupDaemon *pKupDaemon)
+BupJob::BupJob(BackupPlan &pBackupPlan, const QString &pDestinationPath, const QString &pLogFilePath, KupDaemon *pKupDaemon)
    :BackupJob(pBackupPlan, pDestinationPath, pLogFilePath, pKupDaemon)
 {
 	mFsckProcess.setOutputChannelMode(KProcess::SeparateChannels);
@@ -35,6 +21,8 @@ BupJob::BupJob(const BackupPlan &pBackupPlan, const QString &pDestinationPath, c
 	mSaveProcess.setOutputChannelMode(KProcess::SeparateChannels);
 	mPar2Process.setOutputChannelMode(KProcess::SeparateChannels);
 	setCapabilities(KJob::Suspendable);
+	mHarmlessErrorCount = 0;
+	mAllErrorsHarmless = false;
 }
 
 void BupJob::performJob() {
@@ -47,7 +35,8 @@ void BupJob::performJob() {
 		                                         "The <application>bup</application> program is "
 		                                         "needed but could not be found, maybe it is not installed?"));
 		return;
-	} else if(mBackupPlan.mGenerateRecoveryInfo && lExitCode != 0) {
+	}
+	if(mBackupPlan.mGenerateRecoveryInfo && lExitCode != 0) {
 		jobFinishedError(ErrorWithoutLog, xi18nc("@info notification",
 		                                         "The <application>par2</application> program is "
 		                                         "needed but could not be found, maybe it is not installed?"));
@@ -66,8 +55,8 @@ void BupJob::performJob() {
 	mLogStream << quoteArgs(lInitProcess.program()) << endl;
 	if(lInitProcess.execute() != 0) {
 		mLogStream << QString::fromUtf8(lInitProcess.readAllStandardError()) << endl;
-		mLogStream << endl << QStringLiteral("Kup did not successfully complete the bup backup job: "
-		                                     "failed to initialize backup destination.") << endl;
+		mLogStream << QStringLiteral("Kup did not successfully complete the bup backup job: "
+		                             "failed to initialize backup destination.") << endl;
 		jobFinishedError(ErrorWithLog, xi18nc("@info notification", "Backup destination could not be initialised. "
 		                                                            "See log file for more details."));
 		return;
@@ -77,6 +66,7 @@ void BupJob::performJob() {
 		mFsckProcess << QStringLiteral("bup");
 		mFsckProcess << QStringLiteral("-d") << mDestinationPath;
 		mFsckProcess << QStringLiteral("fsck") << QStringLiteral("--quick");
+		mFsckProcess << QStringLiteral("-j") << QString::number(qMin(4, QThread::idealThreadCount()));
 
 		connect(&mFsckProcess, SIGNAL(finished(int,QProcess::ExitStatus)), SLOT(slotCheckingDone(int,QProcess::ExitStatus)));
 		connect(&mFsckProcess, SIGNAL(started()), SLOT(slotCheckingStarted()));
@@ -94,11 +84,15 @@ void BupJob::slotCheckingStarted() {
 }
 
 void BupJob::slotCheckingDone(int pExitCode, QProcess::ExitStatus pExitStatus) {
-	mLogStream << QString::fromUtf8(mFsckProcess.readAllStandardError());
+	QString lErrors = QString::fromUtf8(mFsckProcess.readAllStandardError());
+	if(!lErrors.isEmpty()) {
+		mLogStream << lErrors << endl;
+	}
+	mLogStream << "Exit code: " << pExitCode << endl;
 	if(pExitStatus != QProcess::NormalExit || pExitCode != 0) {
-		mLogStream << endl << QStringLiteral("Kup did not successfully complete the bup backup job: "
-		                                     "failed integrity check. Your backups could be "
-		                                     "corrupted! See above for details.") << endl;
+		mLogStream << QStringLiteral("Kup did not successfully complete the bup backup job: "
+		                             "failed integrity check. Your backups could be "
+		                             "corrupted! See above for details.") << endl;
 		if(mBackupPlan.mGenerateRecoveryInfo) {
 			jobFinishedError(ErrorSuggestRepair, xi18nc("@info notification",
 			                                            "Failed backup integrity check. Your backups could be corrupted! "
@@ -118,6 +112,10 @@ void BupJob::slotCheckingDone(int pExitCode, QProcess::ExitStatus pExitStatus) {
 		mIndexProcess << QStringLiteral("--exclude");
 		mIndexProcess << lExclude;
 	}
+	QString lExcludesPath = mBackupPlan.absoluteExcludesFilePath();
+	if(mBackupPlan.mExcludePatterns && QFileInfo::exists(lExcludesPath)) {
+		mIndexProcess << QStringLiteral("--exclude-rx-from") << lExcludesPath;
+	}
 	mIndexProcess << mBackupPlan.mPathsIncluded;
 
 	connect(&mIndexProcess, SIGNAL(finished(int,QProcess::ExitStatus)), SLOT(slotIndexingDone(int,QProcess::ExitStatus)));
@@ -132,9 +130,13 @@ void BupJob::slotIndexingStarted() {
 }
 
 void BupJob::slotIndexingDone(int pExitCode, QProcess::ExitStatus pExitStatus) {
-	mLogStream << QString::fromUtf8(mIndexProcess.readAllStandardError());
+	QString lErrors = QString::fromUtf8(mIndexProcess.readAllStandardError());
+	if(!lErrors.isEmpty()) {
+		mLogStream << lErrors << endl;
+	}
+	mLogStream << "Exit code: " << pExitCode << endl;
 	if(pExitStatus != QProcess::NormalExit || pExitCode != 0) {
-		mLogStream << endl << QStringLiteral("Kup did not successfully complete the bup backup job: failed to index everything.") << endl;
+		mLogStream << QStringLiteral("Kup did not successfully complete the bup backup job: failed to index everything.") << endl;
 		jobFinishedError(ErrorWithLog, xi18nc("@info notification", "Failed to analyze files. "
 		                                                            "See log file for more details."));
 		return;
@@ -160,25 +162,31 @@ void BupJob::slotSavingStarted() {
 }
 
 void BupJob::slotSavingDone(int pExitCode, QProcess::ExitStatus pExitStatus) {
-	mLogStream << QString::fromUtf8(mSaveProcess.readAllStandardError());
+	slotReadBupErrors();
+	mLogStream << "Exit code: " << pExitCode << endl;
 	if(pExitStatus != QProcess::NormalExit || pExitCode != 0) {
-		mLogStream << endl << QStringLiteral("Kup did not successfully complete the bup backup job: "
-		                                     "failed to save everything.") << endl;
-		jobFinishedError(ErrorWithLog, xi18nc("@info notification", "Failed to save backup. "
-		                                                            "See log file for more details."));
-		return;
+		if(mAllErrorsHarmless) {
+			mLogStream << QStringLiteral("Only harmless errors detected by Kup.") << endl;
+		} else {
+			mLogStream << QStringLiteral("Kup did not successfully complete the bup backup job: "
+			                             "failed to save everything.") << endl;
+			jobFinishedError(ErrorWithLog, xi18nc("@info notification", "Failed to save backup. "
+			                                                            "See log file for more details."));
+			return;
+		}
 	}
 	if(mBackupPlan.mGenerateRecoveryInfo) {
 		mPar2Process << QStringLiteral("bup");
 		mPar2Process << QStringLiteral("-d") << mDestinationPath;
 		mPar2Process << QStringLiteral("fsck") << QStringLiteral("-g");
+		mPar2Process << QStringLiteral("-j") << QString::number(qMin(4, QThread::idealThreadCount()));
 
 		connect(&mPar2Process, SIGNAL(finished(int,QProcess::ExitStatus)), SLOT(slotRecoveryInfoDone(int,QProcess::ExitStatus)));
 		connect(&mPar2Process, SIGNAL(started()), SLOT(slotRecoveryInfoStarted()));
 		mLogStream << quoteArgs(mPar2Process.program()) << endl;
 		mPar2Process.start();
 	} else {
-		mLogStream << endl << QStringLiteral("Kup successfully completed the bup backup job at ")
+		mLogStream << QStringLiteral("Kup successfully completed the bup backup job at ")
 		           << QLocale().toString(QDateTime::currentDateTime()) << endl;
 		jobFinishedSuccess();
 	}
@@ -190,54 +198,70 @@ void BupJob::slotRecoveryInfoStarted() {
 }
 
 void BupJob::slotRecoveryInfoDone(int pExitCode, QProcess::ExitStatus pExitStatus) {
-	mLogStream << QString::fromUtf8(mPar2Process.readAllStandardError());
+	QString lErrors = QString::fromUtf8(mPar2Process.readAllStandardError());
+	if(!lErrors.isEmpty()) {
+		mLogStream << lErrors << endl;
+	}
+	mLogStream << "Exit code: " << pExitCode << endl;
 	if(pExitStatus != QProcess::NormalExit || pExitCode != 0) {
-		mLogStream << endl << QStringLiteral("Kup did not successfully complete the bup backup job: "
-		                                     "failed to generate recovery info.") << endl;
+		mLogStream << QStringLiteral("Kup did not successfully complete the bup backup job: "
+		                             "failed to generate recovery info.") << endl;
 		jobFinishedError(ErrorWithLog, xi18nc("@info notification", "Failed to generate recovery info for the backup. "
 		                                                            "See log file for more details."));
 	} else {
-		mLogStream << endl << QStringLiteral("Kup successfully completed the bup backup job.") << endl;
+		mLogStream << QStringLiteral("Kup successfully completed the bup backup job.") << endl;
 		jobFinishedSuccess();
 	}
 }
 
 void BupJob::slotReadBupErrors() {
 	bool lValidInfo = false, lValidFileName = false;
-	qulonglong lCopiedKBytes, lTotalKBytes, lCopiedFiles, lTotalFiles;
-	ulong lSpeedKBps, lPercent = 0;
+	qulonglong lCopiedKBytes = 0, lTotalKBytes = 0, lCopiedFiles = 0, lTotalFiles = 0;
+	ulong lSpeedKBps = 0, lPercent = 0;
 	QString lFileName;
+	QRegularExpression lProgressRegExp(QStringLiteral("(\\d+)/(\\d+)k, (\\d+)/(\\d+) files\\) \\S* (?:(\\d+)k/s|)"));
+	QRegularExpression lErrorCountRegExp(QStringLiteral("WARNING: (\\d+) errors encountered while saving."));
 
 	QTextStream lStream(mSaveProcess.readAllStandardError());
-	QString lLine;
-	while(lStream.readLineInto(&lLine, 500)) {
-//		mLogStream << "read a line: " << lLine << endl;
-		if(lLine.startsWith(QStringLiteral("Reading index:"))) {
-			continue;
-		} else if(lLine.startsWith(QStringLiteral("bloom:"))) {
-			continue;
-		} else if(lLine.startsWith(QStringLiteral("midx:"))) {
-			continue;
-		} else if(lLine.startsWith(QStringLiteral("Saving:"))) {
-			QRegularExpression lRegExp(QStringLiteral("(\\d+)/(\\d+)k, (\\d+)/(\\d+) files\\) \\S* (?:(\\d+)k/s|)"));
-			QRegularExpressionMatch lMatch = lRegExp.match(lLine);
-			if(lMatch.hasMatch()) {
-				lCopiedKBytes = lMatch.captured(1).toULongLong();
-				lTotalKBytes = lMatch.captured(2).toULongLong();
-				lCopiedFiles = lMatch.captured(3).toULongLong();
-				lTotalFiles = lMatch.captured(4).toULongLong();
-				lSpeedKBps = lMatch.captured(5).toULong();
-				if(lTotalKBytes != 0) {
-					lPercent = qMax(100*lCopiedKBytes/lTotalKBytes, (qulonglong)1);
+	QString lRawLine;
+	while(lStream.readLineInto(&lRawLine)) {
+		const QStringList lList = lRawLine.split(QChar::CarriageReturn);
+		for(const QString &lLine: lList) {
+			//		mLogStream << "read a line: " << lLine << endl;
+			if(lLine.startsWith(QStringLiteral("Reading index:")) || lLine.startsWith(QStringLiteral("bloom:"))
+			        || lLine.startsWith(QStringLiteral("midx:"))) {
+				continue;
+			}
+			if(lLine.startsWith(QStringLiteral("Saving:"))) {
+				QRegularExpressionMatch lMatch = lProgressRegExp.match(lLine);
+				if(lMatch.hasMatch()) {
+					lCopiedKBytes = lMatch.captured(1).toULongLong();
+					lTotalKBytes = lMatch.captured(2).toULongLong();
+					lCopiedFiles = lMatch.captured(3).toULongLong();
+					lTotalFiles = lMatch.captured(4).toULongLong();
+					lSpeedKBps = lMatch.captured(5).toULong();
+					if(lTotalKBytes != 0) {
+						lPercent = qMax(100*lCopiedKBytes/lTotalKBytes, static_cast<qulonglong>(1));
+					}
+					lValidInfo = true;
 				}
-				lValidInfo = true;
+			} else if(lLine.startsWith(QStringLiteral("[Errno 2]"))) {
+				mHarmlessErrorCount++;
+				mLogStream << lLine << endl;
+			} else if(lLine.startsWith(QStringLiteral("WARNING:"))) {
+				QRegularExpressionMatch lMatch = lErrorCountRegExp.match(lLine);
+				if(lMatch.hasMatch()) {
+					int lTotalErrors = lMatch.captured(1).toInt();
+					mAllErrorsHarmless = lTotalErrors == mHarmlessErrorCount;
+				}
+				mLogStream << lLine << endl;
+			} else if((lLine.at(0) == ' ' || lLine.at(0) == 'A' || lLine.at(0) == 'M') && lLine.at(1) == ' ' && lLine.at(2) == '/') {
+				lFileName = lLine;
+				lFileName.remove(0, 2);
+				lValidFileName = true;
+			} else if(!lLine.startsWith(QStringLiteral("D /"))) {
+				mLogStream << lLine << endl;
 			}
-		} else if((lLine.at(0) == ' ' || lLine.at(0) == 'A' || lLine.at(0) == 'M') && lLine.at(1) == ' ' && lLine.at(2) == '/') {
-			lLine.remove(0, 2);
-			lFileName = lLine;
-			lValidFileName = true;
-		} else if(!lLine.startsWith("D /")) {
-			mLogStream << lLine << endl;
 		}
 	}
 	if(mInfoRateLimiter.hasExpired(200)) {
