@@ -1,22 +1,6 @@
-/***************************************************************************
- *   Copyright Simon Persson                                               *
- *   simonpersson1@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
- ***************************************************************************/
+// SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
+//
+// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
 
 #ifndef PLANEXECUTOR_H
 #define PLANEXECUTOR_H
@@ -44,10 +28,10 @@ class PlanExecutor : public QObject
 	Q_OBJECT
 public:
 	PlanExecutor(BackupPlan *pPlan, KupDaemon *pKupDaemon);
-	virtual ~PlanExecutor();
+	~PlanExecutor() override;
 
 	BackupPlan::ScheduleType scheduleType() {
-		return (BackupPlan::ScheduleType)mPlan->mScheduleType;
+		return static_cast<BackupPlan::ScheduleType>(mPlan->mScheduleType);
 	}
 
 	bool busy() {
@@ -85,6 +69,7 @@ protected slots:
 
 	void exitBackupRunningState(bool pWasSuccessful);
 	void enterAvailableState();
+	void askUserOrStart(const QString& pUserQuestion);
 	void enterNotAvailableState();
 
 	void askUser(const QString &pQuestion);
@@ -93,7 +78,7 @@ protected slots:
 	void notifyBackupFailed(KJob *pFailedJob);
 	void discardFailNotification();
 
-	void notifyBackupSucceeded();
+	static void notifyBackupSucceeded();
 
 	void integrityCheckFinished(KJob *pJob);
 	void discardIntegrityNotification();
@@ -105,7 +90,7 @@ protected slots:
 
 protected:
 	BackupJob *createBackupJob();
-	bool powerSaveActive();
+	static bool powerSaveActive();
 
 	KNotification *mQuestion;
 	QTimer *mSchedulingTimer;
