@@ -1,36 +1,20 @@
-/***************************************************************************
- *   Copyright Simon Persson                                               *
- *   simonpersson1@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
- ***************************************************************************/
+// SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
+//
+// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
 
 #include "rsyncjob.h"
 #include "kuputils.h"
 
-#include <signal.h>
+#include <csignal>
 
+#include <QDir>
 #include <QRegularExpression>
 #include <QTextStream>
 
 #include <KLocalizedString>
 
 
-
-RsyncJob::RsyncJob(const BackupPlan &pBackupPlan, const QString &pDestinationPath,
+RsyncJob::RsyncJob(BackupPlan &pBackupPlan, const QString &pDestinationPath,
                    const QString &pLogFilePath, KupDaemon *pKupDaemon)
    :BackupJob(pBackupPlan, pDestinationPath, pLogFilePath, pKupDaemon)
 {
@@ -50,14 +34,24 @@ void RsyncJob::performJob() {
 		return;
 	}
 
+	// Remove this and the performMigration method when it is likely that all users of pre 0.8 kup have now started using post 0.8.
+	if(mBackupPlan.mBackupVersion < 1 && mBackupPlan.mLastCompleteBackup.isValid() && mBackupPlan.mPathsIncluded.length() == 1) {
+		mLogStream << QStringLiteral("Migrating saved files to new location, after update to version 0.8 of Kup.") << endl;
+		if(!performMigration()) {
+			mLogStream << QStringLiteral("Migration failed. Continuing backup save regardless, may result in files stored twice.") << endl;
+		}
+	}
+	mBackupPlan.mBackupVersion = 1;
+	mBackupPlan.save();
+
 	mLogStream << QStringLiteral("Kup is starting rsync backup job at ")
 	           << QLocale().toString(QDateTime::currentDateTime())
 	           << endl;
 
 	emit description(this, i18n("Checking what to copy"));
 	mRsyncProcess << QStringLiteral("rsync") << QStringLiteral("-avX")
-	              << QStringLiteral("--delete-excluded");
-	mRsyncProcess << QStringLiteral("--info=progress2") << QStringLiteral("--no-i-r");
+	              << QStringLiteral("--delete-excluded") << QStringLiteral("--delete-before")
+	              << QStringLiteral("--info=progress2");
 
 	QStringList lIncludeNames;
 	foreach(const QString &lInclude, mBackupPlan.mPathsIncluded) {
@@ -67,7 +61,7 @@ void RsyncJob::performJob() {
 		// There would be a naming conflict in the destination folder, instead use full paths.
 		mRsyncProcess << QStringLiteral("-R");
 		foreach(const QString &lExclude, mBackupPlan.mPathsExcluded) {
-			mRsyncProcess << QStringLiteral("--exclude=") + lExclude;
+			mRsyncProcess << QStringLiteral("--exclude") << lExclude;
 		}
 	} else {
 		// when NOT using -R, need to then strip parent paths from excludes, everything above the
@@ -78,26 +72,18 @@ void RsyncJob::performJob() {
 				QString lIncludeWithSlash = lInclude;
 				ensureTrailingSlash(lIncludeWithSlash);
 				if(lExclude.startsWith(lIncludeWithSlash)) {
-					if(mBackupPlan.mPathsIncluded.length() == 1) {
-						lExclude.remove(0, lInclude.length());
-					} else {
-						lExclude.remove(0, lInclude.length() - lIncludeNames.at(i).length() - 1);
-					}
+					lExclude.remove(0, lInclude.length() - lIncludeNames.at(i).length() - 1);
 					break;
 				}
 			}
-			mRsyncProcess << QStringLiteral("--exclude=") + lExclude;
+			mRsyncProcess << QStringLiteral("--exclude") << lExclude;
 		}
 	}
-
-	if(mBackupPlan.mPathsIncluded.count() == 1) {
-		// Add a slash to the end so that rsync takes only the contents of the folder, not the folder itself.
-		QString lInclude = mBackupPlan.mPathsIncluded.first();
-		ensureTrailingSlash(lInclude);
-		mRsyncProcess << lInclude;
-	} else  {
-		mRsyncProcess << mBackupPlan.mPathsIncluded;
+	QString lExcludesPath = mBackupPlan.absoluteExcludesFilePath();
+	if(mBackupPlan.mExcludePatterns && QFileInfo::exists(lExcludesPath)) {
+		mRsyncProcess << QStringLiteral("--exclude-from") << lExcludesPath;
 	}
+	mRsyncProcess << mBackupPlan.mPathsIncluded;
 	mRsyncProcess << mDestinationPath;
 
 	connect(&mRsyncProcess, SIGNAL(started()), SLOT(slotRsyncStarted()));
@@ -114,24 +100,30 @@ void RsyncJob::slotRsyncStarted() {
 }
 
 void RsyncJob::slotRsyncFinished(int pExitCode, QProcess::ExitStatus pExitStatus) {
-	mLogStream << QString::fromUtf8(mRsyncProcess.readAllStandardError());
-	if(pExitStatus != QProcess::NormalExit || pExitCode != 0) {
-		mLogStream << endl << QStringLiteral("Kup did not successfully complete the rsync backup job.") << endl;
+	QString lErrors = QString::fromUtf8(mRsyncProcess.readAllStandardError());
+	if(!lErrors.isEmpty()) {
+		mLogStream << lErrors << endl;
+	}
+	mLogStream << "Exit code: " << pExitCode << endl;
+	// exit code 24 means source files disappeared during copying. No reason to worry about that.
+	if(pExitStatus != QProcess::NormalExit || (pExitCode != 0 && pExitCode != 24)) {
+		mLogStream << QStringLiteral("Kup did not successfully complete the rsync backup job.") << endl;
 		jobFinishedError(ErrorWithLog, xi18nc("@info notification", "Failed to save backup. "
 		                                                            "See log file for more details."));
 	} else {
-		mLogStream << endl << QStringLiteral("Kup successfully completed the rsync backup job at ")
+		mLogStream << QStringLiteral("Kup successfully completed the rsync backup job at ")
 		           << QLocale().toString(QDateTime::currentDateTime()) << endl;
 		jobFinishedSuccess();
 	}
 }
 
 void RsyncJob::slotReadRsyncOutput() {
-	bool lValidInfo = false, lValidFileName = false;
+	bool lValidInfo = false;
+	bool lValidFileName = false;
 	QString lFileName;
-	ulong lPercent;
-	qulonglong lTransfered;
-	double lSpeed;
+	ulong lPercent{};
+	qulonglong lTransfered{};
+	double lSpeed{};
 	QChar lUnit;
 	QRegularExpression lProgressInfoExp(QStringLiteral("^\\s+([\\d,\\.]+)\\s+(\\d+)%\\s+(\\d*[,\\.]\\d+)(\\S)"));
 	// very ugly and rough indication that this is a file path... what else to do..
@@ -144,7 +136,7 @@ void RsyncJob::slotReadRsyncOutput() {
 		if(lMatch.hasMatch()) {
 			lValidInfo = true;
 			lTransfered = lMatch.captured(1).remove(',').remove('.').toULongLong();
-			lPercent = qMax(lMatch.captured(2).toULong(), (ulong)1);
+			lPercent = qMax(lMatch.captured(2).toULong(), 1UL);
 			lSpeed = QLocale().toDouble(lMatch.captured(3));
 			lUnit = lMatch.captured(4).at(0);
 		} else {
@@ -165,7 +157,7 @@ void RsyncJob::slotReadRsyncOutput() {
 			} else if(lUnit == 'G') {
 				lSpeed *= 1e9;
 			}
-			emitSpeed(lSpeed);
+			emitSpeed(static_cast<ulong>(lSpeed));
 			if(lPercent > 5) { // the rounding to integer percent gives big error with small percentages
 				setProcessedAmount(KJob::Bytes, lTransfered);
 				setTotalAmount(KJob::Bytes, lTransfered*100/lPercent);
@@ -181,7 +173,10 @@ void RsyncJob::slotReadRsyncOutput() {
 
 bool RsyncJob::doKill() {
 	setError(KilledJobError);
-	return 0 == ::kill(mRsyncProcess.pid(), SIGINT);
+	if(0 == ::kill(mRsyncProcess.pid(), SIGINT)) {
+		return mRsyncProcess.waitForFinished();
+	}
+	return false;
 }
 
 bool RsyncJob::doSuspend() {
@@ -192,3 +187,28 @@ bool RsyncJob::doResume() {
 	return 0 == ::kill(mRsyncProcess.pid(), SIGCONT);
 }
 
+// This migration moves files from being stored directly in destination folder, to
+// being stored in a subfolder of the destination. The subfolder is named same as the
+// source folder. This migration will only be done if there is exactly one source folder.
+bool RsyncJob::performMigration() {
+	QString lSourceDirName = lastPartOfPath(mBackupPlan.mPathsIncluded.first()); //only one included
+	QDir lDestDir = QDir(mDestinationPath);
+	mLogStream << QStringLiteral("Creating directory named ") << lSourceDirName << " inside of " << mDestinationPath << endl;
+	if(!lDestDir.mkdir(lSourceDirName)) {
+		mLogStream << QStringLiteral("Failed to create directory, aborting migration.") << endl;
+		return false;
+	}
+	foreach(const QString &lContent, lDestDir.entryList(QDir::AllEntries | QDir::NoDotAndDotDot)) {
+		if(lContent != lSourceDirName) {
+			QString lDest = lSourceDirName + QLatin1Char('/') + lContent;
+			mLogStream << QStringLiteral("Renaming ") << lContent << " to " << lDest << endl;
+			if(!lDestDir.rename(lContent, lDest)) {
+				mLogStream << QStringLiteral("Failed to rename, aborting migration.") << endl;
+				return false;
+			}
+		}
+	}
+	mLogStream << QStringLiteral("File migration completed.") << endl;
+	return true;
+}
+
