@@ -1,39 +1,25 @@
-/***************************************************************************
- *   Copyright Simon Persson                                               *
- *   simonpersson1@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
- ***************************************************************************/
+// SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
+//
+// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
 
-#include "kupdaemon.h"
 #include "mergedvfs.h"
+#include "kupdaemon.h"
 #include "vfshelpers.h"
 #include "kupfiledigger_debug.h"
 
-#include <QDebug>
-#include <QDir>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <QDBusInterface>
 
+#include <QDBusInterface>
+#include <QDir>
+#include <QGuiApplication>
+
+#include <utility>
 #include <git2/branch.h>
 #include <sys/stat.h>
 
-typedef QMap<QString, MergedNode *> NameMap;
-typedef QMapIterator<QString, MergedNode *> NameMapIterator;
+using NameMap = QMap<QString, MergedNode *>;
+using NameMapIterator = QMapIterator<QString, MergedNode *>;
 
 git_repository *MergedNode::mRepository = nullptr;
 
@@ -58,17 +44,17 @@ MergedNode::MergedNode(QObject *pParent, const QString &pName, uint pMode)
 }
 
 void MergedNode::getBupUrl(int pVersionIndex, QUrl *pComplete, QString *pRepoPath,
-                           QString *pBranchName, quint64 *pCommitTime, QString *pPathInRepo) const {
+                           QString *pBranchName, qint64 *pCommitTime, QString *pPathInRepo) const {
 	QList<const MergedNode *> lStack;
 	const MergedNode *lNode = this;
 	while(lNode != nullptr) {
 		lStack.append(lNode);
 		lNode = qobject_cast<const MergedNode *>(lNode->parent());
 	}
-	const MergedRepository *lRepo = qobject_cast<const MergedRepository *>(lStack.takeLast());
+	const auto lRepo = qobject_cast<const MergedRepository *>(lStack.takeLast());
 	if(pComplete) {
-		pComplete->setUrl("bup://" + lRepo->objectName() + '/' + lRepo->mBranchName + '/' +
-		                  vfsTimeToString(mVersionList.at(pVersionIndex)->mCommitTime));
+		pComplete->setUrl("bup://" + lRepo->objectName() + lRepo->mBranchName + '/' +
+		                  vfsTimeToString(static_cast<git_time_t>(mVersionList.at(pVersionIndex)->mCommitTime)));
 	}
 	if(pRepoPath) {
 		*pRepoPath = lRepo->objectName();
@@ -98,7 +84,9 @@ MergedNodeList &MergedNode::subNodes() {
 	if(mSubNodes == nullptr) {
 		mSubNodes = new MergedNodeList();
 		if(S_ISDIR(mMode)) {
+			QGuiApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
 			generateSubNodes();
+			QGuiApplication::restoreOverrideCursor();
 		}
 	}
 	return *mSubNodes;
@@ -106,9 +94,9 @@ MergedNodeList &MergedNode::subNodes() {
 
 void MergedNode::askForIntegrityCheck() {
 	int lAnswer = KMessageBox::questionYesNo(nullptr, xi18nc("@info messagebox",
-	                                                     "Could not read this backup archive. Perhaps some files "
-	                                                     "have become corrupted. Do you want to run an integrity "
-	                                                     "check to test this?"));
+	                                                         "Could not read this backup archive. Perhaps some files "
+	                                                         "have become corrupted. Do you want to run an integrity "
+	                                                         "check to test this?"));
 	if(lAnswer == KMessageBox::Yes) {
 		QDBusInterface lInterface(KUP_DBUS_SERVICE_NAME, KUP_DBUS_OBJECT_PATH);
 		if(lInterface.isValid()) {
@@ -130,12 +118,12 @@ void MergedNode::generateSubNodes() {
 		VintStream *lMetadataStream = nullptr;
 		const git_tree_entry *lTreeEntry = git_tree_entry_byname(lTree, ".bupm");
 		if(lTreeEntry != nullptr && 0 == git_blob_lookup(&lMetadataBlob, mRepository, git_tree_entry_id(lTreeEntry))) {
-			lMetadataStream = new VintStream(git_blob_rawcontent(lMetadataBlob), git_blob_rawsize(lMetadataBlob), this);
+			lMetadataStream = new VintStream(git_blob_rawcontent(lMetadataBlob), static_cast<int>(git_blob_rawsize(lMetadataBlob)), this);
 			Metadata lMetadata;
 			readMetadata(*lMetadataStream, lMetadata); // the first entry is metadata for the directory itself, discard it.
 		}
 
-		uint lEntryCount = git_tree_entrycount(lTree);
+		ulong lEntryCount = git_tree_entrycount(lTree);
 		for(uint i = 0; i < lEntryCount; ++i) {
 			uint lMode;
 			const git_oid *lOid;
@@ -180,17 +168,21 @@ void MergedNode::generateSubNodes() {
 					                                              lCurrentVersion->mModifiedDate, 0));
 				}
 			} else {
-				quint64 lModifiedDate;
+				qint64 lModifiedDate = lCurrentVersion->mModifiedDate;
+				qint64 lSize = -1;
 				Metadata lMetadata;
 				if(lMetadataStream != nullptr && 0 == readMetadata(*lMetadataStream, lMetadata)) {
 					lModifiedDate = lMetadata.mMtime;
-				} else {
-					lModifiedDate = lCurrentVersion->mModifiedDate;
+					lSize = lMetadata.mSize;
 				}
 				if(!lAlreadySeen) {
-					lSubNode->mVersionList.append(new VersionData(lChunked, lOid,
-					                                              lCurrentVersion->mCommitTime,
-					                                              lModifiedDate));
+					VersionData *lVersionData;
+					if(lSize >= 0) {
+						lVersionData = new VersionData(lOid, lCurrentVersion->mCommitTime, lModifiedDate, static_cast<quint64>(lSize));
+					} else {
+						lVersionData = new VersionData(lChunked, lOid, lCurrentVersion->mCommitTime, lModifiedDate);
+					}
+					lSubNode->mVersionList.append(lVersionData);
 				}
 			}
 		}
@@ -200,14 +192,14 @@ void MergedNode::generateSubNodes() {
 		}
 		git_tree_free(lTree);
 	}
-	qSort(mSubNodes->begin(), mSubNodes->end(), mergedNodeLessThan);
+	std::sort(mSubNodes->begin(), mSubNodes->end(), mergedNodeLessThan);
 	foreach(MergedNode *lNode, *mSubNodes) {
-		qSort(lNode->mVersionList.begin(), lNode->mVersionList.end(), versionGreaterThan);
+		std::sort(lNode->mVersionList.begin(), lNode->mVersionList.end(), versionGreaterThan);
 	}
 }
 
-MergedRepository::MergedRepository(QObject *pParent, const QString &pRepositoryPath, const QString &pBranchName)
-   : MergedNode(pParent, pRepositoryPath, DEFAULT_MODE_DIRECTORY), mBranchName(pBranchName)
+MergedRepository::MergedRepository(QObject *pParent, const QString &pRepositoryPath, QString pBranchName)
+   : MergedNode(pParent, pRepositoryPath, DEFAULT_MODE_DIRECTORY), mBranchName(std::move(pBranchName))
 {
 	if(!objectName().endsWith(QLatin1Char('/'))) {
 		setObjectName(objectName() + QLatin1Char('/'));
@@ -287,13 +279,13 @@ bool MergedRepository::permissionsOk() {
 }
 
 uint qHash(git_oid pOid) {
-	return qHash(QByteArray::fromRawData((char *)pOid.id, GIT_OID_RAWSZ));
+	return qHash(QByteArray::fromRawData(reinterpret_cast<const char *>(pOid.id), GIT_OID_RAWSZ));
 }
 
 
 bool operator ==(const git_oid &pOidA, const git_oid &pOidB) {
-	QByteArray a = QByteArray::fromRawData((char *)pOidA.id, GIT_OID_RAWSZ);
-	QByteArray b = QByteArray::fromRawData((char *)pOidB.id, GIT_OID_RAWSZ);
+	QByteArray a = QByteArray::fromRawData(reinterpret_cast<const char *>(pOidA.id), GIT_OID_RAWSZ);
+	QByteArray b = QByteArray::fromRawData(reinterpret_cast<const char *>(pOidB.id), GIT_OID_RAWSZ);
 	return a == b;
 }
 
@@ -307,7 +299,7 @@ quint64 VersionData::size() {
 	} else {
 		git_blob *lBlob;
 		if(0 == git_blob_lookup(&lBlob, MergedNode::mRepository, &mOid)) {
-			mSize = git_blob_rawsize(lBlob);
+			mSize = static_cast<quint64>(git_blob_rawsize(lBlob));
 			git_blob_free(lBlob);
 		} else {
 			mSize = 0;
