@@ -1,22 +1,6 @@
-/***************************************************************************
- *   Copyright Simon Persson                                               *
- *   simonpersson1@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
- ***************************************************************************/
+// SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
+//
+// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
 
 #include "restoredialog.h"
 #include "ui_restoredialog.h"
@@ -38,18 +22,18 @@
 #include <QDir>
 #include <QInputDialog>
 #include <QPushButton>
-#include <QSignalMapper>
 #include <QTimer>
+#include <utility>
 
-#define KUP_TMP_RESTORE_FOLDER QStringLiteral("_kup_temporary_restore_folder_")
+static const QString cKupTempRestoreFolder = QStringLiteral("_kup_temporary_restore_folder_");
 
-RestoreDialog::RestoreDialog(const BupSourceInfo &pPathInfo, QWidget *parent)
-   : QDialog(parent), mUI(new Ui::RestoreDialog), mSourceInfo(pPathInfo)
+RestoreDialog::RestoreDialog(BupSourceInfo pPathInfo, QWidget *parent)
+   : QDialog(parent), mUI(new Ui::RestoreDialog), mSourceInfo(std::move(pPathInfo))
 {
 	mSourceFileName = mSourceInfo.mPathInRepo.section(QDir::separator(), -1);
 
 	qCDebug(KUPFILEDIGGER) << "Starting restore dialog for repo: " << mSourceInfo.mRepoPath
-	          << ", restoring: " << mSourceInfo.mPathInRepo;
+	                       << ", restoring: " << mSourceInfo.mPathInRepo;
 
 	mUI->setupUi(this);
 
@@ -66,16 +50,11 @@ RestoreDialog::RestoreDialog(const BupSourceInfo &pPathInfo, QWidget *parent)
 	mMessageWidget = new KMessageWidget(this);
 	mMessageWidget->setWordWrap(true);
 	mUI->mTopLevelVLayout->insertWidget(0, mMessageWidget);
+	mMessageWidget->hide();
 	connect(mUI->mDestBackButton, SIGNAL(clicked()), mMessageWidget, SLOT(hide()));
 	connect(mUI->mDestNextButton, SIGNAL(clicked()), SLOT(checkDestinationSelection()));
-
-	mSignalMapper = new QSignalMapper(this);
-	connect(mSignalMapper, SIGNAL(mapped(int)), mUI->mStackedWidget, SLOT(setCurrentIndex(int)));
-	mSignalMapper->setMapping(mUI->mDestBackButton, 0);
-	connect(mUI->mDestBackButton, SIGNAL(clicked()), mSignalMapper, SLOT(map()));
-	mSignalMapper->setMapping(mUI->mOverwriteBackButton, 0);
-	connect(mUI->mOverwriteBackButton, SIGNAL(clicked()), mSignalMapper, SLOT(map()));
-
+	connect(mUI->mDestBackButton, &QPushButton::clicked, this, [this]{mUI->mStackedWidget->setCurrentIndex(0);});
+	connect(mUI->mOverwriteBackButton, &QPushButton::clicked, this, [this]{mUI->mStackedWidget->setCurrentIndex(0);});
 	connect(mUI->mConfirmButton, SIGNAL(clicked()), SLOT(fileOverwriteConfirmed()));
 	connect(mUI->mOpenDestinationButton, SIGNAL(clicked()), SLOT(openDestinationFolder()));
 }
@@ -115,7 +94,7 @@ void RestoreDialog::setCustomDestination() {
 		mDirSelector->expandToUrl(QUrl::fromLocalFile(lDirPath));
 		mUI->mDestinationVLayout->insertWidget(0, mDirSelector);
 
-		QPushButton *lNewFolderButton = new QPushButton(QIcon::fromTheme(QStringLiteral("folder-new")),
+		auto lNewFolderButton = new QPushButton(QIcon::fromTheme(QStringLiteral("folder-new")),
 		                                                xi18nc("@action:button","New Folder..."));
 		connect(lNewFolderButton, SIGNAL(clicked()), SLOT(createNewFolder()));
 		mUI->mDestinationHLayout->insertWidget(0, lNewFolderButton);
@@ -187,7 +166,7 @@ void RestoreDialog::startPrechecks() {
 				lDir.setFilter(QDir::AllEntries | QDir::Hidden | QDir::System | QDir::NoDotAndDotDot);
 				if(lDir.count() > 0) { // destination dir exists and is non-empty.
 					mRestorationPath.append(QDir::separator());
-					mRestorationPath.append(KUP_TMP_RESTORE_FOLDER);
+					mRestorationPath.append(cKupTempRestoreFolder);
 				}
 				// make bup not restore the source folder itself but instead it's contents
 				mSourceInfo.mPathInRepo.append(QDir::separator());
@@ -198,15 +177,21 @@ void RestoreDialog::startPrechecks() {
 			} else {
 				mUI->mFileConflictList->addItem(mFolderToCreate.absoluteFilePath());
 				mRestorationPath.append(QDir::separator());
-				mRestorationPath.append(KUP_TMP_RESTORE_FOLDER);
+				mRestorationPath.append(cKupTempRestoreFolder);
 			}
 		}
 		qCDebug(KUPFILEDIGGER) << "Starting source file listing job on: " << mSourceInfo.mBupKioPath;
 		KIO::ListJob *lListJob = KIO::listRecursive(mSourceInfo.mBupKioPath, KIO::HideProgressInfo);
+		auto lJobTracker = new KWidgetJobTracker(this);
+		lJobTracker->registerJob(lListJob);
+		QWidget *lProgressWidget = lJobTracker->widget(lListJob);
+		mUI->mSourceScanLayout->insertWidget(2, lProgressWidget);
+		lProgressWidget->show();
 		connect(lListJob, SIGNAL(entries(KIO::Job*,KIO::UDSEntryList)),
 		        SLOT(collectSourceListing(KIO::Job*,KIO::UDSEntryList)));
 		connect(lListJob, SIGNAL(result(KJob*)), SLOT(sourceListingCompleted(KJob*)));
 		lListJob->start();
+		mUI->mStackedWidget->setCurrentIndex(4);
 	} else {
 		mDirectoriesCount = 0;
 		mSourceSize = mSourceInfo.mSize;
@@ -214,7 +199,7 @@ void RestoreDialog::startPrechecks() {
 		mRestorationPath = mDestination.absolutePath();
 		if(mDestination.exists() || mDestination.fileName() != mSourceFileName) {
 			mRestorationPath.append(QDir::separator());
-			mRestorationPath.append(KUP_TMP_RESTORE_FOLDER);
+			mRestorationPath.append(cKupTempRestoreFolder);
 			if(mDestination.exists()) {
 				mUI->mFileConflictList->addItem(mDestination.absoluteFilePath());
 			}
@@ -235,13 +220,12 @@ void RestoreDialog::collectSourceListing(KIO::Job *pJob, const KIO::UDSEntryList
 			}
 		} else {
 			if(!it->isLink()) {
-				quint64 lEntrySize = it->numberValue(KIO::UDSEntry::UDS_SIZE);
+				auto lEntrySize = static_cast<quint64>(it->numberValue(KIO::UDSEntry::UDS_SIZE));
 				mSourceSize += lEntrySize;
 				mFileSizes.insert(mSourceFileName + QDir::separator() + lEntryName, lEntrySize);
 			}
 			if(!mSavedWorkingDirectory.isEmpty()) {
-				QFileInfo lFileInfo(lEntryName);
-				if(lFileInfo.exists()) {
+				if(QFileInfo::exists(lEntryName)) {
 					mUI->mFileConflictList->addItem(lEntryName);
 				}
 			}
@@ -260,6 +244,7 @@ void RestoreDialog::sourceListingCompleted(KJob *pJob) {
 		                              pJob->errorString()));
 		mMessageWidget->setMessageType(KMessageWidget::Error);
 		mMessageWidget->animatedShow();
+		mUI->mStackedWidget->setCurrentIndex(0);
 	} else {
 		completePrechecks();
 	}
@@ -274,13 +259,14 @@ void RestoreDialog::completePrechecks() {
 		                              "Please choose a different destination or free some space."));
 		mMessageWidget->setMessageType(KMessageWidget::Error);
 		mMessageWidget->animatedShow();
+		mUI->mStackedWidget->setCurrentIndex(0);
 	} else if(mUI->mFileConflictList->count() > 0) {
 		qCDebug(KUPFILEDIGGER) << "Detected file conflicts.";
 		if(mSourceInfo.mIsDirectory) {
-			QString lDateString = QLocale().toString(QDateTime::fromTime_t(mSourceInfo.mCommitTime).toLocalTime());
+			QString lDateString = QLocale().toString(QDateTime::fromSecsSinceEpoch(static_cast<qint64>(mSourceInfo.mCommitTime)).toLocalTime());
 			lDateString.replace(QLatin1Char('/'), QLatin1Char('-')); // make sure no slashes in suggested folder name
 			mUI->mNewFolderNameEdit->setText(mSourceFileName +
-			                                 xi18nc("added to the suggested filename when restoring, %1 is the time when backup was taken",
+			                                 xi18nc("added to the suggested filename when restoring, %1 is the time when backup was saved",
 			                                       " - saved at %1", lDateString));
 			mUI->mConflictTitleLabel->setText(xi18nc("@info", "Folder already exists, please choose a solution"));
 		} else {
@@ -305,12 +291,11 @@ void RestoreDialog::fileOverwriteConfirmed() {
 			mMessageWidget->setMessageType(KMessageWidget::Error);
 			mMessageWidget->animatedShow();
 			return;
-		} else {
-			mFolderToCreate = QFileInfo(mDestination.absoluteFilePath() + QDir::separator() + mUI->mNewFolderNameEdit->text());
-			mRestorationPath = mFolderToCreate.absoluteFilePath();
-			if(!mSourceInfo.mPathInRepo.endsWith(QDir::separator())) {
-				mSourceInfo.mPathInRepo.append(QDir::separator());
-			}
+		}
+		mFolderToCreate = QFileInfo(mDestination.absoluteFilePath() + QDir::separator() + mUI->mNewFolderNameEdit->text());
+		mRestorationPath = mFolderToCreate.absoluteFilePath();
+		if(!mSourceInfo.mPathInRepo.endsWith(QDir::separator())) {
+			mSourceInfo.mPathInRepo.append(QDir::separator());
 		}
 	}
 	startRestoring();
@@ -320,18 +305,18 @@ void RestoreDialog::startRestoring() {
 	QString lSourcePath(QDir::separator());
 	lSourcePath.append(mSourceInfo.mBranchName);
 	lSourcePath.append(QDir::separator());
-	QDateTime lCommitTime = QDateTime::fromTime_t(mSourceInfo.mCommitTime);
+	QDateTime lCommitTime = QDateTime::fromSecsSinceEpoch(static_cast<qint64>(mSourceInfo.mCommitTime));
 	lSourcePath.append(lCommitTime.toString(QStringLiteral("yyyy-MM-dd-hhmmss")));
 	lSourcePath.append(mSourceInfo.mPathInRepo);
 	qCDebug(KUPFILEDIGGER) << "Starting restore. Source path: " << lSourcePath << ", restore path: " << mRestorationPath;
-	RestoreJob *lRestoreJob = new RestoreJob(mSourceInfo.mRepoPath, lSourcePath, mRestorationPath,
+	auto lRestoreJob = new RestoreJob(mSourceInfo.mRepoPath, lSourcePath, mRestorationPath,
 	                                         mDirectoriesCount, mSourceSize, mFileSizes);
 	if(mJobTracker == nullptr) {
 		mJobTracker = new KWidgetJobTracker(this);
 	}
 	mJobTracker->registerJob(lRestoreJob);
 	QWidget *lProgressWidget = mJobTracker->widget(lRestoreJob);
-	mUI->mRestoreProgressLayout->insertWidget(1, lProgressWidget);
+	mUI->mRestoreProgressLayout->insertWidget(2, lProgressWidget);
 	lProgressWidget->show();
 	connect(lRestoreJob, SIGNAL(result(KJob*)), SLOT(restoringCompleted(KJob*)));
 	lRestoreJob->start();
@@ -373,7 +358,7 @@ void RestoreDialog::createNewFolder() {
 	bool lUserAccepted;
 	QUrl lUrl = mDirSelector->url();
 	QString lNameSuggestion = xi18nc("default folder name when creating a new folder", "New Folder");
-	if(QFileInfo(lUrl.adjusted(QUrl::StripTrailingSlash).path() + '/' + lNameSuggestion).exists()) {
+	if(QFileInfo::exists(lUrl.adjusted(QUrl::StripTrailingSlash).path() + '/' + lNameSuggestion)) {
 		lNameSuggestion = KIO::suggestName(lUrl, lNameSuggestion);
 	}
 
@@ -410,11 +395,11 @@ void RestoreDialog::openDestinationFolder() {
 	KRun::runUrl(QUrl::fromLocalFile(mSourceInfo.mIsDirectory ?
 	                                    mFolderToCreate.absoluteFilePath() :
 	                                    mDestination.absolutePath()),
-	             QStringLiteral("inode/directory"), nullptr);
+	             QStringLiteral("inode/directory"), nullptr, KRun::RunFlags());
 }
 
 void RestoreDialog::moveFolder() {
-	if(!mRestorationPath.endsWith(KUP_TMP_RESTORE_FOLDER)) {
+	if(!mRestorationPath.endsWith(cKupTempRestoreFolder)) {
 		mUI->mRestorationStackWidget->setCurrentIndex(2);
 		mUI->mCloseButton->show();
 		qCDebug(KUPFILEDIGGER) << "Overall restore operation completed.";
