@@ -1,38 +1,22 @@
-/***************************************************************************
- *   Copyright Simon Persson                                               *
- *   simonpersson1@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
- ***************************************************************************/
-
-#include <QDir>
-#include <QDebug>
-#include <KLocalizedString>
+// SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
+//
+// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
 
 #include "restorejob.h"
 
+#include <QDir>
+#include <KLocalizedString>
+#include <utility>
+
 #include <unistd.h>
 #include <sys/resource.h>
 #ifdef Q_OS_LINUX
 #include <sys/syscall.h>
 #endif
 
-RestoreJob::RestoreJob(const QString &pRepositoryPath, const QString &pSourcePath, const QString &pRestorationPath,
+RestoreJob::RestoreJob(QString pRepositoryPath, QString pSourcePath, QString pRestorationPath,
                        int pTotalDirCount, quint64 pTotalFileSize, const QHash<QString, quint64> &pFileSizes)
- : KJob(), mRepositoryPath(pRepositoryPath), mSourcePath(pSourcePath), mRestorationPath(pRestorationPath),
+ : mRepositoryPath(std::move(pRepositoryPath)), mSourcePath(std::move(pSourcePath)), mRestorationPath(std::move(pRestorationPath)),
    mTotalDirCount(pTotalDirCount), mTotalFileSize(pTotalFileSize), mFileSizes(pFileSizes)
 {
 	setCapabilities(Killable);
@@ -44,9 +28,9 @@ RestoreJob::RestoreJob(const QString &pRepositoryPath, const QString &pSourcePat
 void RestoreJob::start() {
 	setTotalAmount(Bytes, mTotalFileSize);
 	setProcessedAmount(Bytes, 0);
-	setTotalAmount(Files, mFileSizes.count());
+	setTotalAmount(Files, static_cast<quint64>(mFileSizes.count()));
 	setProcessedAmount(Files, 0);
-	setTotalAmount(Directories, mTotalDirCount);
+	setTotalAmount(Directories, static_cast<quint64>(mTotalDirCount));
 	setProcessedAmount(Directories, 0);
 	setPercent(0);
 	mRestoreProcess << QStringLiteral("bup");
@@ -117,6 +101,6 @@ void RestoreJob::makeNice(int pPid) {
 	// See linux documentation Documentation/block/ioprio.txt for details of the syscall
 	syscall(SYS_ioprio_set, 1, pPid, 3 << 13 | 7);
 #endif
-	setpriority(PRIO_PROCESS, pPid, 19);
+	setpriority(PRIO_PROCESS, static_cast<uint>(pPid), 19);
 }
 
