@@ -1,22 +1,6 @@
-/***************************************************************************
- *   Copyright Simon Persson                                               *
- *   simonpersson1@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
- ***************************************************************************/
+// SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
+//
+// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
 
 #include "versionlistdelegate.h"
 #include "versionlistmodel.h"
@@ -33,16 +17,17 @@
 #include <QGraphicsOpacityEffect>
 #include <QPropertyAnimation>
 #include <QPushButton>
+#include <QtMath>
+#include <utility>
 
-#define cMargin 4
+static const int cMargin = 4;
 
-Button::Button(QString pText, QWidget *pParent)
-   : QObject() // don't make it owned by pParent
-{
+Button::Button(QString pText, QWidget *pParent) {
+	// intentionally don't make this QObject owned by pParent
 	mStyleOption.initFrom(pParent);
 	mStyleOption.features = QStyleOptionButton::None;
 	mStyleOption.state = QStyle::State_Enabled;
-	mStyleOption.text = pText;
+	mStyleOption.text = std::move(pText);
 
 	const QSize lContentsSize = mStyleOption.fontMetrics.size(Qt::TextSingleLine, mStyleOption.text);
 	mStyleOption.rect = QRect(QPoint(0, 0),
@@ -57,38 +42,38 @@ void Button::setPosition(const QPoint &pTopRight) {
 }
 
 void Button::paint(QPainter *pPainter, float pOpacity) {
-	pPainter->setOpacity(pOpacity);
+	pPainter->setOpacity(static_cast<qreal>(pOpacity));
 	QApplication::style()->drawControl(QStyle::CE_PushButton, &mStyleOption, pPainter);
 }
 
 bool Button::event(QEvent *pEvent) {
-	QMouseEvent *lMouseEvent = static_cast<QMouseEvent *>(pEvent);
+	auto lMouseEvent = dynamic_cast<QMouseEvent *>(pEvent);
 	bool lActivated = false;
 	switch(pEvent->type()) {
-		case QEvent::MouseMove:
-			if(mStyleOption.rect.contains(lMouseEvent->pos())) {
-				if(!(mStyleOption.state & QStyle::State_MouseOver)) {
-					mStyleOption.state |= QStyle::State_MouseOver;
-					if(mPushed) {
-						mStyleOption.state |= QStyle::State_Sunken;
-						mStyleOption.state &= ~QStyle::State_Raised;
-					}
-					mParent->update(mStyleOption.rect);
-				}
-			} else {
-				if(mStyleOption.state & QStyle::State_MouseOver) {
-					mStyleOption.state &= ~QStyle::State_MouseOver;
-					if(mPushed) {
-						mStyleOption.state &= ~QStyle::State_Sunken;
-						mStyleOption.state |= QStyle::State_Raised;
-					}
-					mParent->update(mStyleOption.rect);
+	case QEvent::MouseMove:
+		if(mStyleOption.rect.contains(lMouseEvent->pos())) {
+			if(!(mStyleOption.state & QStyle::State_MouseOver)) {
+				mStyleOption.state |= QStyle::State_MouseOver;
+				if(mPushed) {
+					mStyleOption.state |= QStyle::State_Sunken;
+					mStyleOption.state &= ~QStyle::State_Raised;
 				}
+				mParent->update(mStyleOption.rect);
 			}
+		} else {
+			if(mStyleOption.state & QStyle::State_MouseOver) {
+				mStyleOption.state &= ~QStyle::State_MouseOver;
+				if(mPushed) {
+					mStyleOption.state &= ~QStyle::State_Sunken;
+					mStyleOption.state |= QStyle::State_Raised;
+				}
+				mParent->update(mStyleOption.rect);
+			}
+		}
 		break;
 	case QEvent::MouseButtonPress:
 		if(lMouseEvent->button() == Qt::LeftButton && !mPushed &&
-		      (mStyleOption.state & QStyle::State_MouseOver)) {
+		        (mStyleOption.state & QStyle::State_MouseOver)) {
 			mPushed = true;
 			mStyleOption.state |= QStyle::State_Sunken;
 			mStyleOption.state &= ~QStyle::State_Raised;
@@ -107,7 +92,7 @@ bool Button::event(QEvent *pEvent) {
 		}
 		break;
 	case QEvent::KeyPress: {
-		QKeyEvent *lKeyEvent = static_cast<QKeyEvent *>(pEvent);
+		auto lKeyEvent = dynamic_cast<QKeyEvent *>(pEvent);
 		if((mStyleOption.state & QStyle::State_HasFocus)) {
 			if(lKeyEvent->key() == Qt::Key_Left || lKeyEvent->key() == Qt::Key_Right) {
 				mStyleOption.state &= ~QStyle::State_HasFocus;
@@ -118,6 +103,7 @@ bool Button::event(QEvent *pEvent) {
 				lActivated = true;
 			}
 		}
+		break;
 	}
 	default:
 		break;
@@ -136,21 +122,21 @@ VersionItemAnimation::VersionItemAnimation(QWidget *pParent)
 	connect(mOpenButton, SIGNAL(focusChangeRequested(bool)), SLOT(changeFocus(bool)), Qt::QueuedConnection);
 	mRestoreButton = new Button(xi18nc("@action:button", "Restore"), pParent);
 	connect(mRestoreButton, SIGNAL(focusChangeRequested(bool)), SLOT(changeFocus(bool)), Qt::QueuedConnection);
-	QPropertyAnimation *lHeightAnimation = new QPropertyAnimation(this, "extraHeight", this);
+	auto lHeightAnimation = new QPropertyAnimation(this, "extraHeight", this);
 	lHeightAnimation->setStartValue(0.0);
 	lHeightAnimation->setEndValue(1.0);
 	lHeightAnimation->setDuration(300);
 	lHeightAnimation->setEasingCurve(QEasingCurve::InOutBack);
 	addAnimation(lHeightAnimation);
 
-	QPropertyAnimation *lWidgetOpacityAnimation = new QPropertyAnimation(this, "opacity", this);
+	auto lWidgetOpacityAnimation = new QPropertyAnimation(this, "opacity", this);
 	lWidgetOpacityAnimation->setStartValue(0.0);
 	lWidgetOpacityAnimation->setEndValue(1.0);
 	lWidgetOpacityAnimation->setDuration(300);
 	addAnimation(lWidgetOpacityAnimation);
 }
 
-void VersionItemAnimation::setExtraHeight(float pExtraHeight) {
+void VersionItemAnimation::setExtraHeight(qreal pExtraHeight) {
 	mExtraHeight = pExtraHeight;
 	emit sizeChanged(mIndex);
 }
@@ -191,8 +177,7 @@ VersionListDelegate::VersionListDelegate(QAbstractItemView *pItemView, QObject *
 	pItemView->viewport()->setMouseTracking(true);
 }
 
-VersionListDelegate::~VersionListDelegate() {
-}
+VersionListDelegate::~VersionListDelegate()=default;
 
 void VersionListDelegate::paint(QPainter *pPainter, const QStyleOptionViewItem &pOption, const QModelIndex &pIndex) const {
 	QStyle * lStyle = QApplication::style();
@@ -204,7 +189,7 @@ void VersionListDelegate::paint(QPainter *pPainter, const QStyleOptionViewItem &
 
 	QRect lSizeDisplayBounds;
 	if(!pIndex.data(VersionIsDirectoryRole).toBool()) {
-		QString lSizeText = KFormat().formatByteSize((double)pIndex.data(VersionSizeRole).toULongLong());
+		QString lSizeText = KFormat().formatByteSize(static_cast<double>(pIndex.data(VersionSizeRole).toULongLong()));
 		pPainter->drawText(lMarginRect, Qt::AlignRight | Qt::AlignTop, lSizeText, &lSizeDisplayBounds);
 	}
 	QString lDateText = pOption.fontMetrics.elidedText(pIndex.data().toString(), Qt::ElideRight,
@@ -235,11 +220,11 @@ QSize VersionListDelegate::sizeHint(const QStyleOptionViewItem &pOption, const Q
 	VersionItemAnimation *lAnimation = mActiveAnimations.value(pIndex);
 	if(lAnimation != nullptr) {
 		int lButtonHeight = lAnimation->mOpenButton->mStyleOption.rect.height();
-		lExtraHeight = lAnimation->extraHeight() * (lButtonHeight + cMargin);
+		lExtraHeight = qCeil(lAnimation->extraHeight() * (lButtonHeight + cMargin));
 		lExtraWidth = lAnimation->mOpenButton->mStyleOption.rect.width() +
 		              lAnimation->mRestoreButton->mStyleOption.rect.width();
 	}
-	return QSize(lExtraWidth, cMargin*2 + pOption.fontMetrics.height() + lExtraHeight);
+	return {lExtraWidth, cMargin*2 + pOption.fontMetrics.height() + lExtraHeight};
 }
 
 bool VersionListDelegate::eventFilter(QObject *pObject, QEvent *pEvent) {
@@ -289,7 +274,7 @@ void VersionListDelegate::reset() {
 }
 
 void VersionListDelegate::reclaimAnimation() {
-	VersionItemAnimation *lAnimation = static_cast<VersionItemAnimation *>(sender());
+	auto lAnimation = qobject_cast<VersionItemAnimation *>(sender());
 	if(lAnimation->direction() == QAbstractAnimation::Backward) {
 		mInactiveAnimations.append(lAnimation);
 		foreach(VersionItemAnimation *lActiveAnimation, mActiveAnimations) {
