@@ -1,22 +1,6 @@
-/***************************************************************************
- *   Copyright Simon Persson                                               *
- *   simonpersson1@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
- ***************************************************************************/
+// SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
+//
+// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
 
 #ifndef BACKUPPLANWIDGET_H
 #define BACKUPPLANWIDGET_H
@@ -46,11 +30,11 @@ class FileScanner : public QObject {
 	Q_OBJECT
 public:
 	FileScanner();
-	bool event(QEvent *pEvent) Q_DECL_OVERRIDE;
+	bool event(QEvent *pEvent) override;
 
 public slots:
-	void includePath(QString pPath);
-	void excludePath(QString pPath);
+	void includePath(const QString &pPath);
+	void excludePath(const QString &pPath);
 
 signals:
 	void unreadablesChanged(QPair<QSet<QString>, QSet<QString>>);
@@ -81,13 +65,13 @@ protected:
 class FolderSelectionWidget : public QWidget {
 	Q_OBJECT
 public:
-	FolderSelectionWidget(FolderSelectionModel *pModel, QWidget *pParent = 0);
+	explicit FolderSelectionWidget(FolderSelectionModel *pModel, QWidget *pParent = nullptr);
 	virtual ~FolderSelectionWidget();
 
 public slots:
 	void setHiddenFoldersVisible(bool pVisible);
 	void expandToShowSelections();
-	void setUnreadables(QPair<QSet<QString>, QSet<QString>> pUnreadables);
+	void setUnreadables(const QPair<QSet<QString>, QSet<QString>> &pUnreadables);
 	void setSymlinks(QHash<QString,QString> pSymlinks);
 	void updateMessage();
 	void executeExcludeAction();
@@ -162,11 +146,11 @@ public:
 	QPushButton *mConfigureButton;
 	KPageWidget *mConfigPages;
 	BackupPlan *mBackupPlan;
-	DriveSelection *mDriveSelection;
-	KLineEdit *mDriveDestEdit;
-	QRadioButton *mVersionedRadio;
-	QRadioButton *mSyncedRadio;
-	FolderSelectionWidget *mSourceSelectionWidget;
+	DriveSelection *mDriveSelection{};
+	KLineEdit *mDriveDestEdit{};
+	QRadioButton *mVersionedRadio{};
+	QRadioButton *mSyncedRadio{};
+	FolderSelectionWidget *mSourceSelectionWidget{};
 
 protected slots:
 	void openDriveDestDialog();
