@@ -1,22 +1,6 @@
-/***************************************************************************
- *   Copyright Simon Persson                                               *
- *   simonpersson1@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
- ***************************************************************************/
+// SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
+//
+// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
 
 #include "driveselection.h"
 #include "driveselectiondelegate.h"
@@ -55,7 +39,7 @@ DriveSelection::DriveSelection(BackupPlan *pBackupPlan, QWidget *parent)
 	setWordWrap(true);
 
 	if(!mBackupPlan->mExternalUUID.isEmpty()) {
-		QStandardItem *lItem = new QStandardItem();
+		auto *lItem = new QStandardItem();
 		lItem->setEditable(false);
 		lItem->setData(QString(), DriveSelection::UDI);
 		lItem->setData(mBackupPlan->mExternalUUID, DriveSelection::UUID);
@@ -84,7 +68,7 @@ QString DriveSelection::mountPathOfSelectedDrive() const {
 		findItem(DriveSelection::UUID, mSelectedUuid, &lItem);
 		if(lItem != nullptr) {
 			Solid::Device lDevice(lItem->data(DriveSelection::UDI).toString());
-			Solid::StorageAccess *lAccess = lDevice.as<Solid::StorageAccess>();
+			auto *lAccess = lDevice.as<Solid::StorageAccess>();
 			if(lAccess) {
 				return lAccess->filePath();
 			}
@@ -98,7 +82,7 @@ void DriveSelection::deviceAdded(const QString &pUdi) {
 	if(!lDevice.is<Solid::StorageDrive>()) {
 		return;
 	}
-	Solid::StorageDrive *lDrive = lDevice.as<Solid::StorageDrive>();
+	auto *lDrive = lDevice.as<Solid::StorageDrive>();
 	if(!lDrive->isHotpluggable() && !lDrive->isRemovable()) {
 		return;
 	}
@@ -124,7 +108,7 @@ void DriveSelection::delayedDeviceAdded() {
 	// filter out some volumes that should not be visible
 	QList<Solid::Device> lVolumeDeviceList;
 	foreach(Solid::Device lVolumeDevice, lDeviceList) {
-		Solid::StorageVolume *lVolume = lVolumeDevice.as<Solid::StorageVolume>();
+		auto *lVolume = lVolumeDevice.as<Solid::StorageVolume>();
 		if(lVolume && !lVolume->isIgnored() && (
 		         lVolume->usage() == Solid::StorageVolume::FileSystem ||
 		         lVolume->usage() == Solid::StorageVolume::Encrypted)) {
@@ -133,11 +117,11 @@ void DriveSelection::delayedDeviceAdded() {
 	}
 
 	// simplest attempt at getting the same partition numbering every time a device is plugged in
-	qSort(lVolumeDeviceList.begin(), lVolumeDeviceList.end(), deviceLessThan);
+	std::sort(lVolumeDeviceList.begin(), lVolumeDeviceList.end(), deviceLessThan);
 
 	int lPartitionNumber = 1;
 	foreach(Solid::Device lVolumeDevice, lVolumeDeviceList) {
-		Solid::StorageVolume *lVolume = lVolumeDevice.as<Solid::StorageVolume>();
+		auto *lVolume = lVolumeDevice.as<Solid::StorageVolume>();
 		QString lUuid = lVolume->uuid();
 		if(lUuid.isEmpty()) { //seems to happen for vfat partitions
 			lUuid += lParentDevice.description();
@@ -167,11 +151,9 @@ void DriveSelection::delayedDeviceAdded() {
 		lItem->setData(mSyncedBackupType && lVolume->fsType() == QStringLiteral("vfat"),
 		               DriveSelection::SymlinkLossWarning);
 
-		Solid::StorageAccess *lAccess = lVolumeDevice.as<Solid::StorageAccess>();
+		auto *lAccess = lVolumeDevice.as<Solid::StorageAccess>();
 		connect(lAccess, SIGNAL(accessibilityChanged(bool,QString)), SLOT(accessabilityChanged(bool,QString)));
-		if(!lAccess->isAccessible()) {
-			lAccess->setup();
-		} else {
+		if(lAccess->isAccessible()) {
 			KDiskFreeSpaceInfo lInfo = KDiskFreeSpaceInfo::freeSpaceInfo(lAccess->filePath());
 			if(lInfo.isValid()) {
 				lItem->setData(lInfo.size(), DriveSelection::TotalSpace);
@@ -182,6 +164,9 @@ void DriveSelection::delayedDeviceAdded() {
 				mSelectedAndAccessible = true;
 				emit selectedDriveIsAccessibleChanged(true);
 			}
+		} else if(lVolume->usage() != Solid::StorageVolume::Encrypted) {
+			// Don't bother the user with password prompt just for sake of storage volume space info
+			lAccess->setup();
 		}
 		if(lNeedsToBeAdded) {
 			mDrivesModel->appendRow(lItem);
@@ -218,7 +203,7 @@ void DriveSelection::accessabilityChanged(bool pAccessible, const QString &pUdi)
 	if(lItem != nullptr) {
 		if(pAccessible) {
 			Solid::Device lDevice(pUdi);
-			Solid::StorageAccess *lAccess = lDevice.as<Solid::StorageAccess>();
+			auto *lAccess = lDevice.as<Solid::StorageAccess>();
 			if(lAccess) {
 				KDiskFreeSpaceInfo lInfo = KDiskFreeSpaceInfo::freeSpaceInfo(lAccess->filePath());
 				if(lInfo.isValid()) {
@@ -249,7 +234,7 @@ void DriveSelection::updateSelection(const QItemSelection &pSelected, const QIte
 		QString lUdiOfSelected = lIndex.data(DriveSelection::UDI).toString();
 		if(!lUdiOfSelected.isEmpty()) {
 			Solid::Device lDevice(lUdiOfSelected);
-			Solid::StorageAccess *lAccess = lDevice.as<Solid::StorageAccess>();
+			auto *lAccess = lDevice.as<Solid::StorageAccess>();
 			if(lAccess != nullptr) {
 				lIsAccessible = lAccess->isAccessible();
 			}
@@ -280,7 +265,8 @@ void DriveSelection::paintEvent(QPaintEvent *pPaintEvent) {
 void DriveSelection::setSelectedDrive(const QString &pUuid) {
 	if(pUuid == mSelectedUuid) {
 		return;
-	} else if(pUuid.isEmpty()) {
+	}
+	if(pUuid.isEmpty()) {
 		clearSelection();
 	} else {
 		QStandardItem *lItem;
