@@ -1,28 +1,11 @@
-/* This file is part of the KDE Project
-   Copyright (c) 2008 Sebastian Trueg <trueg@kde.org>
-
-   Based on CollectionSetup.cpp from the Amarok project
-   (C) 2003 Scott Wheeler <wheeler@kde.org>
-   (C) 2004 Max Howell <max.howell@methylblue.com>
-   (C) 2004 Mark Kretschmann <markey@web.de>
-   (C) 2008 Seb Ruiz <ruiz@kde.org>
-   (C) 2008-2009 Sebastian Trueg <trueg@kde.org>
-	(C) 2012 Simon Persson <simonpersson1@gmail.com>
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License version 2 as published by the Free Software Foundation.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
-*/
+// SPDX-FileCopyrightText: 2003 Scott Wheeler <wheeler@kde.org>
+// SPDX-FileCopyrightText: 2004 Max Howell <max.howell@methylblue.com>
+// SPDX-FileCopyrightText: 2004 Mark Kretschmann <markey@web.de>
+// SPDX-FileCopyrightText: 2008 Seb Ruiz <ruiz@kde.org>
+// SPDX-FileCopyrightText: 2008 Sebastian Trueg <trueg@kde.org>
+// SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
+//
+// SPDX-License-Identifier: GPL-2.0-only
 
 #include "folderselectionmodel.h"
 #include "kuputils.h"
@@ -38,7 +21,7 @@
 
 namespace {
 
-bool setContainsSubdir(QSet<QString> pSet, const QString &pParentDir) {
+bool setContainsSubdir(const QSet<QString> &pSet, const QString &pParentDir) {
 	// we need the trailing slash to be able to use the startsWith() function to check for parent dirs.
 	QString lPathWithSlash = pParentDir;
 	ensureTrailingSlash(lPathWithSlash);
@@ -181,7 +164,7 @@ void FolderSelectionModel::excludePath(const QString& pPath) {
 	emit dataChanged(index(pPath), findLastLeaf(index(pPath)));
 }
 
-void FolderSelectionModel::setIncludedPaths(QSet<QString> pIncludedPaths) {
+void FolderSelectionModel::setIncludedPaths(const QSet<QString> &pIncludedPaths) {
 	beginResetModel();
 	QSet<QString> lRemoved = mIncludedPaths - pIncludedPaths;
 	QSet<QString> lAdded = pIncludedPaths - mIncludedPaths;
@@ -196,7 +179,7 @@ void FolderSelectionModel::setIncludedPaths(QSet<QString> pIncludedPaths) {
 	endResetModel();
 }
 
-void FolderSelectionModel::setExcludedPaths(QSet<QString> pExcludedPaths) {
+void FolderSelectionModel::setExcludedPaths(const QSet<QString> &pExcludedPaths) {
 	beginResetModel();
 	QSet<QString> lRemoved = mExcludedPaths - pExcludedPaths;
 	QSet<QString> lAdded = pExcludedPaths - mExcludedPaths;
@@ -227,25 +210,21 @@ FolderSelectionModel::InclusionState FolderSelectionModel::inclusionState(const
 	if(mIncludedPaths.contains(pPath)) {
 		return StateIncluded;
 	}
-	else if(mExcludedPaths.contains(pPath)) {
+	if(mExcludedPaths.contains(pPath)) {
 		return StateExcluded;
 	}
-	else {
-		QString lParent = pPath.section(QDir::separator(), 0, -2, QString::SectionSkipEmpty|QString::SectionIncludeLeadingSep);
-		if(lParent.isEmpty()) {
-			return StateNone;
-		}
-		else {
-			InclusionState state = inclusionState(lParent);
-			if(state == StateNone) {
-				return StateNone;
-			} else if(state == StateIncluded || state == StateIncludeInherited) {
-				return StateIncludeInherited;
-			} else {
-				return StateExcludeInherited;
-			}
-		}
+	QString lParent = pPath.section(QDir::separator(), 0, -2, QString::SectionSkipEmpty|QString::SectionIncludeLeadingSep);
+	if(lParent.isEmpty()) {
+		return StateNone;
 	}
+	InclusionState state = inclusionState(lParent);
+	if(state == StateNone) {
+		return StateNone;
+	}
+	if(state == StateIncluded || state == StateIncludeInherited) {
+		return StateIncludeInherited;
+	}
+	return StateExcludeInherited;
 }
 
 bool FolderSelectionModel::hiddenFoldersVisible() const {
