@@ -1,22 +1,7 @@
-/***************************************************************************
- *   Copyright Simon Persson                                               *
- *   simonpersson1@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
- ***************************************************************************/
+// SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
+//
+// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
+
 #include "vfshelpers.h"
 
 #include <QBuffer>
@@ -26,22 +11,22 @@
 #include <unistd.h>
 #include <sys/stat.h>
 
-#define RECORD_END 0
-#define RECORD_PATH 1
-#define RECORD_COMMON 2 // times, user, group, type, perms, etc. (legacy version 1)
-#define RECORD_SYMLINK_TARGET 3
-#define RECORD_POSIX1E_ACL 4 // getfacl(1), setfacl(1), etc.
-#define RECORD_NFSV4_ACL 5 // intended to supplant posix1e acls?
-#define RECORD_LINUX_ATTR 6 // lsattr(1) chattr(1)
-#define RECORD_LINUX_XATTR 7 // getfattr(1) setfattr(1)
-#define RECORD_HARDLINK_TARGET 8 // hard link target
-#define RECORD_COMMON_V2 9 // times, user, group, type, perms, etc.
-
+static const int cRecordEnd = 0;
+//static const int cRecordPath = 1;
+static const int cRecordCommonV1 = 2; // times, user, group, type, perms, etc. (legacy version 1)
+static const int cRecordSymlinkTarget = 3;
+//static const int cRecordPosix1eAcl = 4; // getfacl(1), setfacl(1), etc.
+//static const int cRecordNfsV4Acl = 5; // intended to supplant posix1e acls?
+//static const int cRecordLinuxAttr = 6; // lsattr(1) chattr(1)
+//static const int cRecordLinuxXattr = 7; // getfattr(1) setfattr(1)
+//static const int cRecordHardlinkTarget = 8;
+static const int cRecordCommonV2 = 9; // times, user, group, type, perms, etc.
+static const int cRecordCommonV3 = 10; // times, user, group, type, perms, etc.
 
 VintStream::VintStream(const void *pData, int pSize, QObject *pParent)
    : QObject(pParent)
 {
-	mByteArray = QByteArray::fromRawData((char *)pData, pSize);
+	mByteArray = QByteArray::fromRawData(static_cast<const char *>(pData), pSize);
 	mBuffer = new QBuffer(&mByteArray, this);
 	mBuffer->open(QIODevice::ReadOnly);
 }
@@ -67,15 +52,15 @@ VintStream &VintStream::operator>>(qint64 &pInt) {
 	return *this;
 }
 
-VintStream &VintStream::operator >>(quint64 &pInt) {
+VintStream &VintStream::operator >>(quint64 &pUint) {
 	char c;
 	int lOffset = 0;
-	pInt = 0;
+	pUint = 0;
 	do {
 		if(!mBuffer->getChar(&c)) {
 			throw 1;
 		}
-		pInt |= (c & 0x7F) << lOffset;
+		pUint |= static_cast<quint64>((c & 0x7F) << lOffset);
 		lOffset += 7;
 	} while(c & 0x80);
 	return *this;
@@ -91,18 +76,18 @@ VintStream &VintStream::operator >>(QString &pString) {
 VintStream &VintStream::operator >>(QByteArray &pByteArray) {
 	quint64 lByteCount;
 	*this >> lByteCount;
-	pByteArray.resize(lByteCount);
+	pByteArray.resize(static_cast<int>(lByteCount));
 	if(mBuffer->read(pByteArray.data(), pByteArray.length()) < pByteArray.length()) {
 		throw 1;
 	}
 	return *this;
 }
 
-quint64 Metadata::mDefaultUid;
-quint64 Metadata::mDefaultGid;
+qint64 Metadata::mDefaultUid;
+qint64 Metadata::mDefaultGid;
 bool Metadata::mDefaultsResolved = false;
 
-Metadata::Metadata(quint64 pMode) {
+Metadata::Metadata(qint64 pMode) {
 	mMode = pMode;
 	mAtime = 0;
 	mMtime = 0;
@@ -113,6 +98,7 @@ Metadata::Metadata(quint64 pMode) {
 	}
 	mUid = mDefaultUid;
 	mGid = mDefaultGid;
+	mSize = -1;
 }
 
 int readMetadata(VintStream &pMetadataStream, Metadata &pMetadata) {
@@ -121,23 +107,23 @@ int readMetadata(VintStream &pMetadataStream, Metadata &pMetadata) {
 		do {
 			pMetadataStream >> lTag;
 			switch(lTag) {
-			case RECORD_COMMON: {
+			case cRecordCommonV1: {
 				qint64 lNotUsedInt;
 				quint64 lNotUsedUint, lTempUint;
 				QString lNotUsedString;
 				pMetadataStream >> lNotUsedUint >> lTempUint;
-				pMetadata.mMode = lTempUint;
+				pMetadata.mMode = static_cast<qint64>(lTempUint);
 				pMetadataStream >> lTempUint >> lNotUsedString; // user name
-				pMetadata.mUid = lTempUint;
+				pMetadata.mUid = static_cast<qint64>(lTempUint);
 				pMetadataStream >> lTempUint >> lNotUsedString; // group name
-				pMetadata.mGid = lTempUint;
+				pMetadata.mGid = static_cast<qint64>(lTempUint);
 				pMetadataStream >> lNotUsedUint; // device number
 				pMetadataStream >> pMetadata.mAtime >> lNotUsedUint; //nanoseconds
 				pMetadataStream >> pMetadata.mMtime >> lNotUsedUint; // nanoseconds
 				pMetadataStream >> lNotUsedInt >> lNotUsedUint; // status change time
 				break;
 			}
-			case RECORD_COMMON_V2: {
+			case cRecordCommonV2: {
 				qint64 lNotUsedInt;
 				quint64 lNotUsedUint;
 				QString lNotUsedString;
@@ -150,19 +136,33 @@ int readMetadata(VintStream &pMetadataStream, Metadata &pMetadata) {
 				pMetadataStream >> lNotUsedInt >> lNotUsedUint; // status change time
 				break;
 			}
-			case RECORD_SYMLINK_TARGET: {
+			case cRecordCommonV3: {
+				qint64 lNotUsedInt;
+				quint64 lNotUsedUint;
+				QString lNotUsedString;
+				pMetadataStream >> lNotUsedUint >> pMetadata.mMode;
+				pMetadataStream >> pMetadata.mUid >> lNotUsedString; // user name
+				pMetadataStream >> pMetadata.mGid >> lNotUsedString; // group name
+				pMetadataStream >> lNotUsedInt; // device number
+				pMetadataStream >> pMetadata.mAtime >> lNotUsedUint; //nanoseconds
+				pMetadataStream >> pMetadata.mMtime >> lNotUsedUint; // nanoseconds
+				pMetadataStream >> lNotUsedInt >> lNotUsedUint; // status change time
+				pMetadataStream >> pMetadata.mSize;
+				break;
+			}
+			case cRecordSymlinkTarget: {
 				pMetadataStream >> pMetadata.mSymlinkTarget;
 				break;
 			}
 			default: {
-				if(lTag != RECORD_END) {
+				if(lTag != cRecordEnd) {
 					QByteArray lNotUsed;
 					pMetadataStream >> lNotUsed;
 				}
 				break;
 			}
 			}
-		} while(lTag != RECORD_END);
+		} while(lTag != cRecordEnd);
 	} catch(int) {
 		return 1;
 	}
@@ -178,7 +178,7 @@ quint64 calculateChunkFileSize(const git_oid *pOid, git_repository *pRepository)
 		if(0 != git_tree_lookup(&lTree, pRepository, pOid)) {
 			return 0;
 		}
-		uint lEntryCount = git_tree_entrycount(lTree);
+		ulong lEntryCount = git_tree_entrycount(lTree);
 		const git_tree_entry *lEntry = git_tree_entry_byindex(lTree, lEntryCount - 1);
 		quint64 lEntryOffset;
 		if(!offsetFromName(lEntry, lEntryOffset)) {
@@ -195,7 +195,7 @@ quint64 calculateChunkFileSize(const git_oid *pOid, git_repository *pRepository)
 	if(0 != git_blob_lookup(&lBlob, pRepository, pOid)) {
 		return 0;
 	}
-	lLastChunkSize = git_blob_rawsize(lBlob);
+	lLastChunkSize = static_cast<quint64>(git_blob_rawsize(lBlob));
 	git_blob_free(lBlob);
 	return lLastChunkOffset + lLastChunkSize;
 }
@@ -224,6 +224,6 @@ void getEntryAttributes(const git_tree_entry *pTreeEntry, uint &pMode, bool &pCh
 
 QString vfsTimeToString(git_time_t pTime) {
 	QDateTime lDateTime;
-	lDateTime.setTime_t(pTime);
+	lDateTime.setSecsSinceEpoch(pTime);
 	return lDateTime.toLocalTime().toString(QStringLiteral("yyyy-MM-dd hh:mm"));
 }
