@@ -1,22 +1,6 @@
-/***************************************************************************
- *   Copyright Simon Persson                                               *
- *   simonpersson1@gmail.com                                               *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
- ***************************************************************************/
+// SPDX-FileCopyrightText: 2020 Simon Persson <simon.persson@mykolab.com>
+//
+// SPDX-License-Identifier: LicenseRef-KDE-Accepted-GPL
 
 #include "backupplan.h"
 #include "kuputils.h"
@@ -27,9 +11,10 @@
 
 #include <KFormat>
 #include <KLocalizedString>
+#include <utility>
 
 BackupPlan::BackupPlan(int pPlanNumber, KSharedConfigPtr pConfig, QObject *pParent)
-   :KCoreConfigSkeleton(pConfig, pParent), mPlanNumber(pPlanNumber)
+   :KCoreConfigSkeleton(std::move(pConfig), pParent), mPlanNumber(pPlanNumber)
 {
 	setCurrentGroup(QString(QStringLiteral("Plan/%1")).arg(mPlanNumber));
 
@@ -40,12 +25,13 @@ BackupPlan::BackupPlan(int pPlanNumber, KSharedConfigPtr pConfig, QObject *pPare
 	lDefaultIncludeList << QDir::homePath();
 	addItemStringList(QStringLiteral("Paths included"), mPathsIncluded, lDefaultIncludeList);
 	QStringList lDefaultExcludeList;
-	lDefaultExcludeList << QStandardPaths::standardLocations(QStandardPaths::MusicLocation);
-	lDefaultExcludeList << QStandardPaths::standardLocations(QStandardPaths::MoviesLocation);
 	lDefaultExcludeList << QDir::homePath() + QStringLiteral("/.cache");
 	lDefaultExcludeList << QDir::homePath() + QStringLiteral("/.bup");
 	lDefaultExcludeList << QDir::homePath() + QStringLiteral("/.thumbnails");
 	lDefaultExcludeList << QDir::homePath() + QStringLiteral("/.local/share/Trash");
+	lDefaultExcludeList << QDir::homePath() + QStringLiteral("/.local/share/baloo");
+	lDefaultExcludeList << QDir::homePath() + QStringLiteral("/.local/share/TelegramDesktop/tdata/temp");
+	lDefaultExcludeList << QDir::homePath() + QStringLiteral("/.config/Riot/Cache");
 	QMutableStringListIterator i(lDefaultExcludeList);
 	while(i.hasNext()) {
 		ensureNoTrailingSlash(i.next());
@@ -53,6 +39,7 @@ BackupPlan::BackupPlan(int pPlanNumber, KSharedConfigPtr pConfig, QObject *pPare
 
 	addItemStringList(QStringLiteral("Paths excluded"), mPathsExcluded, lDefaultExcludeList);
 	addItemInt(QStringLiteral("Backup type"), mBackupType);
+	addItemInt(QStringLiteral("Backup version"), mBackupVersion);
 
 	addItemInt(QStringLiteral("Schedule type"), mScheduleType, 2);
 	addItemInt(QStringLiteral("Schedule interval"), mScheduleInterval, 1);
@@ -76,6 +63,8 @@ BackupPlan::BackupPlan(int pPlanNumber, KSharedConfigPtr pConfig, QObject *pPare
 	addItemBool(QStringLiteral("Show hidden folders"), mShowHiddenFolders);
 	addItemBool(QStringLiteral("Generate recovery info"), mGenerateRecoveryInfo);
 	addItemBool(QStringLiteral("Check backups"), mCheckBackups);
+	addItemBool(QStringLiteral("Exclude patterns"), mExcludePatterns);
+	addItemString(QStringLiteral("Exclude patterns file path"), mExcludePatternsPath);
 
 	addItemDateTime(QStringLiteral("Last complete backup"), mLastCompleteBackup);
 	addItemDouble(QStringLiteral("Last backup size"), mLastBackupSize);
@@ -129,7 +118,7 @@ QDateTime BackupPlan::nextScheduledTime() {
 	return mLastCompleteBackup.addSecs(scheduleIntervalInSeconds());
 }
 
-int BackupPlan::scheduleIntervalInSeconds() {
+qint64 BackupPlan::scheduleIntervalInSeconds() {
 	Q_ASSERT(mScheduleType == 1);
 
 	switch(mScheduleIntervalUnit) {
@@ -154,12 +143,12 @@ BackupPlan::Status BackupPlan::backupStatus() {
 		return NO_STATUS;
 	}
 
-	int lStatus = 5; //trigger BAD status if schedule type is something strange
-	int lInterval = 1;
+	qint64 lStatus = 5; //trigger BAD status if schedule type is something strange
+	qint64 lInterval = 1;
 
 	switch(mScheduleType) {
 	case INTERVAL:
-		lStatus = mLastCompleteBackup.secsTo(QDateTime::currentDateTime().toUTC());
+		lStatus = mLastCompleteBackup.secsTo(QDateTime::currentDateTimeUtc());
 		lInterval = scheduleIntervalInSeconds();
 		break;
 	case USAGE:
@@ -170,10 +159,9 @@ BackupPlan::Status BackupPlan::backupStatus() {
 
 	if(lStatus < lInterval)
 		return GOOD;
-	else if(lStatus < lInterval * 3)
+	if(lStatus < lInterval * 3)
 		return MEDIUM;
-	else
-		return BAD;
+	return BAD;
 }
 
 QString BackupPlan::iconName(Status pStatus) {
@@ -185,9 +173,16 @@ QString BackupPlan::iconName(Status pStatus) {
 	case BAD:
 		return QStringLiteral("security-low");
 	case NO_STATUS:
-		return QStringLiteral("");
+		break;
 	}
-	return QStringLiteral("");
+	return QString();
+}
+
+QString BackupPlan::absoluteExcludesFilePath() {
+	if(QDir::isRelativePath(mExcludePatternsPath)) {
+		return QDir::homePath() + QDir::separator() + mExcludePatternsPath;
+	}
+	return mExcludePatternsPath;
 }
 
 void BackupPlan::usrRead() {
